@@ -9,6 +9,7 @@ import os
 import shutil
 import socket
 import time
+import traceback
 from concurrent.futures import ThreadPoolExecutor
 from contextlib import suppress
 from pathlib import Path
@@ -561,7 +562,7 @@ def _make_default_run_script(
         log_interval=log_interval,
     )
 
-    with open(run_script_fname, "w") as f:
+    with open(run_script_fname, "w", encoding="utf-8") as f:
         f.write(template)
 
 
@@ -1005,14 +1006,28 @@ class RunManager(_BaseManager):
         try:
             self.job_manager.task.result()
         except asyncio.InvalidStateError:
-            return "running"
+            status = "running"
         except asyncio.CancelledError:
             status = "cancelled"
         except Exception:
             status = "failed"
+            print("JobManager failed because of the following")
+            traceback.print_exc()
         else:
             status = "finished"
 
+        try:
+            self.database_manager.task.result()
+        except (asyncio.InvalidStateError, asyncio.CancelledError):
+            pass
+        except Exception:
+            status = "failed"
+            print("DatabaseManager failed because of the following")
+            traceback.print_exc()
+
+        if status == "running":
+            return "running"
+
         if self.end_time is None:
             self.end_time = time.time()
         return status
